@@ -32,6 +32,8 @@
 #include <kapplication.h>
 #include <kedittoolbar.h>
 #include <kwin.h>
+#include <ktip.h>
+#include <dcopclient.h>
 
 #include "actions.h" // QSlider.h included by actions.h clashes with netwm #includes
 
@@ -76,6 +78,8 @@ MainWindow::MainWindow( QWidget *parent, const char *name, WFlags f )
 {
     _toolbarVisibilityList.setAutoDelete(true);
 
+    _haveKWin = KApplication::dcopClient()->isApplicationRegistered("kwin");
+
     // Views
     KDockWidget* mainDock = createDockWidget("TVScreen", QPixmap(), 0L, i18n("TV Screen"));
     _screen = new KdetvWidget(mainDock);
@@ -86,9 +90,7 @@ MainWindow::MainWindow( QWidget *parent, const char *name, WFlags f )
     setMainDockWidget(mainDock);
 
     _sideDock = createDockWidget("Sidebar", QPixmap(), 0L, i18n("Channel Sidebar"));
-    Sidebar* side = new Sidebar(_sideDock);
-    side->setScreen( _screen );
-    side->setFocusProxy(_screen);
+    Sidebar* side = new Sidebar(_screen, _sideDock);
     side->createViews();
     _sideDock->setWidget(side);
     _sideDock->setEnableDocking(KDockWidget::DockCorner); // unhiding when it is a top-level widget is broken
@@ -106,10 +108,6 @@ MainWindow::MainWindow( QWidget *parent, const char *name, WFlags f )
              this, SLOT( statusMessage(const QString & ) ) );
     connect( actionCollection(), SIGNAL( clearStatusText() ),
              this, SLOT( clearStatusBar() ) );
-#if 0
-    connect( _screen->driver(), SIGNAL( channelChanged(const QString &) ),
-             statusBar(), SLOT( permanent(const QString & ) ) );
-#endif
     connect( _screen->driver(), SIGNAL( channelChanged(const QString &) ),
              this, SLOT( setCaption(const QString & ) ) );
     connect( _screen->view(), SIGNAL( doubleClicked() ),
@@ -139,6 +137,11 @@ MainWindow::MainWindow( QWidget *parent, const char *name, WFlags f )
     resize(700, 400); // nice default size
     restoreWindowSettings();
 
+    if (_staysOnTop) {
+        KWin::setState(winId(), NET::StaysOnTop);
+    }
+    KWin::setOnAllDesktops(winId(), _sticky);
+
     KMenuBar *mb = menuBar();
     mb->changeItem( mb->idAt(0), i18n("&Channels") );
 
@@ -156,7 +159,7 @@ MainWindow::MainWindow( QWidget *parent, const char *name, WFlags f )
     connect( this, SIGNAL( viewModeChanged(int) ),
              this, SLOT( checkScreenSaver() ) );
 
-    // Creates the status bar
+    // Create the status bar
     statusBar()->insertItem(QString::null, STATUSBAR_MAIN, 1);
     statusBar()->setItemAlignment(STATUSBAR_MAIN, AlignLeft | AlignVCenter);
     statusBar()->insertItem(QString::null, STATUSBAR_PROGRAM, 0, true);
@@ -187,6 +190,8 @@ MainWindow::MainWindow( QWidget *parent, const char *name, WFlags f )
     connect(_screen->driver()->sourceManager(), SIGNAL( sourceChanged(const QString&) ),
             this, SLOT( audioModesChanged() ));
 
+    KTipDialog::showTip(this);
+
     QTimer::singleShot( 0, this, SLOT(restoreViewMode()) );
     QTimer::singleShot( 0, _screen->driver(), SLOT(start()) );
 }
@@ -217,9 +222,8 @@ void MainWindow::createActions()
     // Standard actions
     (void) KStdAction::quit( qApp, SLOT( quit() ), acts );
     _actShowMenubar   = KStdAction::showMenubar( this, SLOT( toggleMenubar() ), acts );
-    // standart statusbar action is available in KDE 3.2, but let's keep compatibility with 3.1 for while
-    _actShowStatusbar = KStdAction::showStatusbar( this, SLOT( toggleStatus() ), acts );
-    connect(_actShowStatusbar, SIGNAL(activated()), this, SLOT(setSettingsDirty()));
+
+    createStandardStatusBarAction();
 
     // Kdetv actions
     _actions = new LibKdetvActions( _screen->driver() );
@@ -231,7 +235,7 @@ void MainWindow::createActions()
     connect( _actions, SIGNAL(launchBindings()), this, SLOT(keyBindings()) );
 
     // View Modes
-    _actShowNorm = new KRadioAction( i18n("&Normal"),        "kdetv",          Key_Home,     acts, "show_normal" );
+    _actShowNorm = new KRadioAction( i18n("&Normal"),        "kdetv",             Key_Home,     acts, "show_normal" );
     _actShowTV   = new KRadioAction( i18n("T&V Mode"),       "inline_image",      Key_PageDown, acts, "show_top_level" );
     _actShowFull = new KRadioAction( i18n("&Full Screen"),   "window_fullscreen", Key_PageUp,   acts, "full_screen" );
     //    _actShowDesk = new KRadioAction( i18n("Video &Desktop"), "frame_image",       0,            acts, "show_video_desktop" );
@@ -269,18 +273,24 @@ void MainWindow::createActions()
                                      SLOT( configureToolbars() ), acts, "config_toolbars");
 
     // Help actions
-    _actWebSite = new KAction( i18n("kdetv Web Site..."), "html", 0,
+    _actWebSite = new KAction( i18n("kdetv Web Site"), "html", 0,
                                this, SLOT( showWebSite() ),
                                acts, "help_view_website" );
+    _actFAQ = new KAction( i18n("kdetv FAQ"), "help", 0,
+                           this, SLOT( showFAQ() ),
+                           acts, "help_view_faq" );
 
     _sleepTime = new KToggleAction( i18n("Sleep Timer"), "kalarm", Key_T,
                                     this, SLOT( sleepTimer() ), acts,
                                     "sleep_timer" );
+    _actShowTips = new KAction( i18n("Tip of the Day"), "ktip", 0,
+                                this, SLOT( showTipOfTheDay() ),
+                                acts, "help_tip_of_the_day" );
 
     // setup import/export actions for channel files
     const QStringList& fread = _screen->driver()->fileFormatsRead();
-    for (QStringList::const_iterator it = fread.begin();
-         it != fread.end();
+    for (QStringList::const_iterator it = fread.constBegin();
+         it != fread.constEnd();
          ++it) {
         ImpExChannelsAction* a = new ImpExChannelsAction(*it + i18n(" File..."), 0, *it,
                                                          _screen->driver(), 1,
@@ -290,8 +300,8 @@ void MainWindow::createActions()
     }
 
     const QStringList& fwrite = _screen->driver()->fileFormatsWrite();
-    for (QStringList::const_iterator it = fwrite.begin();
-         it != fwrite.end();
+    for (QStringList::const_iterator it = fwrite.constBegin();
+         it != fwrite.constEnd();
          ++it) {
         ImpExChannelsAction* a = new ImpExChannelsAction(*it + i18n(" File..."), 0, *it,
                                                          _screen->driver(), 0,
@@ -377,6 +387,7 @@ QPtrList<SettingsDialogPage>* MainWindow::getPages()
     QPtrList<SettingsDialogPage>* p = new QPtrList<SettingsDialogPage>;
 
     p->append(static_cast<SettingsDialogPage*>(new KdetvSettingsWidgetImpl(0L, this)));
+
     return p;
 }
 
@@ -471,7 +482,7 @@ void MainWindow::checkScreenSaver()
         }
         break;
     default:
-        kdDebug() << "MainWindow: checkScreenSaver(): We should never get here!" << endl;
+        kdWarning() << "MainWindow: checkScreenSaver(): We should never get here!" << endl;
         break;
     }
 }
@@ -487,56 +498,72 @@ void MainWindow::configureToolbars()
 
 void MainWindow::saveWindowSettings()
 {
+	kdDebug() << k_funcinfo << "Called" << endl;
     _cfg->setGroup( "Window Geometry" );
 
     _cfg->writeEntry( "View Mode", _viewMode );
-    setViewModeNormal();
 
-    _cfg->writeEntry( "Window Position X", x() );
-    _cfg->writeEntry( "Window Position Y", y() );
-    _cfg->writeEntry( "TopLevel Pos", _topLevelPos );
-    _cfg->writeEntry( "TopLevel Size", _topLevelSize );
-    _cfg->writeEntry( "Disable Screensaver", _disableSaver );
-    _cfg->writeEntry( "Screensaver Mode", _screenSaverMode );
-    _cfg->writeEntry( "Stay on Top", _staysOnTop );
-    _cfg->writeEntry( "Cycle Normal View", _viewNormalEnabled);
-    _cfg->writeEntry( "Cycle FullScreen View", _viewFullEnabled);
-    _cfg->writeEntry( "Cycle TV View", _viewTVEnabled);
-    _cfg->writeEntry( "Cycle Desktop View", _viewDesktopEnabled);
+	/* Make sure sidebar visibility is stored correctly
+	 * even while saving settings in tv mode
+	 */
+	if (_viewMode == ViewTV)
+		setSidebarVisibility(_sidebarVisible);
+
+	_cfg->writeEntry("Window Position X", _pos.x());
+	_cfg->writeEntry("Window Position Y", _pos.y());
+    _cfg->writeEntry("TopLevel Pos", _topLevelPos);
+    _cfg->writeEntry("TopLevel Size", _topLevelSize);
+    _cfg->writeEntry("Disable Screensaver", _disableSaver);
+    _cfg->writeEntry("Screensaver Mode", _screenSaverMode);
+    _cfg->writeEntry("Stay on Top", _staysOnTop);
+    _cfg->writeEntry("Sticky", _sticky);
+    _cfg->writeEntry("No Sticky when fullscreen", _noStickyFull);
+    _cfg->writeEntry("Cycle Normal View", _viewNormalEnabled);
+    _cfg->writeEntry("Cycle FullScreen View", _viewFullEnabled);
+    _cfg->writeEntry("Cycle TV View", _viewTVEnabled);
+    _cfg->writeEntry("Cycle Desktop View", _viewDesktopEnabled);
+    _cfg->writeEntry("Hide Taskbar Button Normal View", _hideTBNormal);
+    _cfg->writeEntry("Hide Taskbar Button Fullscreen View", _hideTBFull);
+    _cfg->writeEntry("Hide Taskbar Button TV View", _hideTBTV);
 
     writeDockConfig(_cfg, "MainWindow Docks");
+	// only save toolbar menubar etc settings if we are in normal mode
+	if (_viewMode == ViewNormal)
     saveMainWindowSettings(_cfg, "MainWindow");
 }
 
 void MainWindow::restoreWindowSettings()
 {
+	kdDebug() << k_funcinfo << "Called" << endl;
     applyMainWindowSettings(_cfg, "MainWindow");
     readDockConfig(_cfg, "MainWindow Docks");
 
     // these are just toggleActions (they do not track widget state)
     _actShowMenubar->setChecked(!menuBar()->isHidden());
-    _actShowStatusbar->setChecked(!statusBar()->isHidden());
     _actShowSidebar->setChecked(!_sideDock->isHidden());
 
     _cfg->setGroup( "Window Geometry" );
     int x = _cfg->readNumEntry( "Window Position X", 0 );
     int y = _cfg->readNumEntry( "Window Position Y", 0 );
-    move( x, y );
+    topLevelWidget()->move( x, y );
 
     QSize defS(400, 300);
     _topLevelPos  = _cfg->readPointEntry("TopLevel Pos");
     _topLevelSize = _cfg->readSizeEntry("TopLevel Size", &defS);
 
-    _staysOnTop = _cfg->readBoolEntry("Stay on Top", false);
-    if (_staysOnTop)
-	KWin::setState(winId(), NET::StaysOnTop);
-    _disableSaver = _cfg->readBoolEntry("Disable Screensaver", true);
-    _screenSaverMode = _cfg->readNumEntry("Screensaver Mode", SaverVisible);
-    _viewNormalEnabled = _cfg->readBoolEntry("Cycle Normal View", true);
-    _viewFullEnabled = _cfg->readBoolEntry("Cycle FullScreen View", true);
-    _viewTVEnabled = _cfg->readBoolEntry("Cycle TV View", true);
-    _viewDesktopEnabled = _cfg->readBoolEntry("Cycle Desktop View", false);
+    _hideTBNormal       = _cfg->readBoolEntry( "Hide Taskbar Button Normal View", false );
+    _hideTBFull         = _cfg->readBoolEntry( "Hide Taskbar Button Fullscreen View", false );
+    _hideTBTV           = _cfg->readBoolEntry( "Hide Taskbar Button TV View", false );
+    _staysOnTop         = _cfg->readBoolEntry("Stay on Top", false);
+    _sticky             = _cfg->readBoolEntry("Sticky", false);
+    _noStickyFull       = _cfg->readBoolEntry("No Sticky when fullscreen", true);
+    _viewNormalEnabled  = _cfg->readBoolEntry("Cycle Normal View", true);
+    _viewFullEnabled    = _cfg->readBoolEntry("Cycle FullScreen View", true);
+    _viewTVEnabled      = _cfg->readBoolEntry("Cycle TV View", true);
+    //    _viewDesktopEnabled = _cfg->readBoolEntry("Cycle Desktop View", false);
     _viewDesktopEnabled = false;
+    _disableSaver       = _cfg->readBoolEntry("Disable Screensaver", true);
+    _screenSaverMode    = _cfg->readNumEntry("Screensaver Mode", SaverVisible);
 
     addDynamicActions();
 }
@@ -545,15 +572,26 @@ void MainWindow::restoreViewMode()
 {
     // Save main window settings & size
     _size = size();
-    _pos  = pos();
+    _pos  = topLevelWidget()->pos();
 
     _cfg->setGroup( "Window Geometry" );
     setViewMode( _cfg->readNumEntry("View Mode", ViewNormal) );
 }
 
+void MainWindow::showTipOfTheDay()
+{
+    KTipDialog::showTip(this, QString::null, true);
+}
+
 void MainWindow::showWebSite()
 {
-    KURL url( i18n("http://www.kwintv.org/") );
+    KURL url( i18n("http://www.kdetv.org/") );
+    KRun::runURL( url, QString("text/html") );
+}
+
+void MainWindow::showFAQ()
+{
+    KURL url( i18n("http://docs.kde.org/development/en/extragear-multimedia/kdetv/faq.html") );
     KRun::runURL( url, QString("text/html") );
 }
 
@@ -569,12 +607,22 @@ void MainWindow::lircCommand(const QString &cmd, unsigned /*repeat*/)
     if (act)
         act->activate();
     else
-        kdDebug() << "lirc: command '" << cmd << "' not recognized" << endl;
+        kdWarning() << "lirc: command '" << cmd << "' not recognized" << endl;
 }
 
 void MainWindow::keyBindings()
 {
-    KKeyDialog::configure(actionCollection());
+    KKeyDialog dlg;
+
+    QPtrList<KXMLGUIClient> c = guiFactory()->clients();
+
+    for(QPtrList<KXMLGUIClient>::const_iterator it = c.constBegin();
+        it != c.constEnd();
+        ++it) {
+        dlg.insert((*it)->actionCollection());
+    }
+
+    dlg.configure();
 }
 
 void MainWindow::setSidebarVisibility(bool v)
@@ -616,7 +664,7 @@ void MainWindow::clearStatusBar()
 
 void MainWindow::slotSleepTimerTimeout()
 {
-    kdDebug() << "Kdetv: sleepTimer timeout reached - quitting client." << endl;
+    kdWarning() << "Kdetv: sleepTimer timeout reached - quitting client." << endl;
     QApplication::exit();
 }
 
@@ -656,6 +704,34 @@ void MainWindow::sleepTimer()
     emit sleepTimerDelay(QString::number(_sleepdelay / 1000 / 60));
 }
 
+void MainWindow::updateTaskbarButton()
+{
+    if( (_hideTBNormal && (_viewMode == ViewNormal))     ||
+        (_hideTBTV     && (_viewMode == ViewTV))         ||
+        (_hideTBFull   && (_viewMode == ViewFullScreen))    ) {
+        setShowTrayIcon( true );
+        KWin::setState(winId(), NET::SkipTaskbar);
+    } else {
+        setShowTrayIcon( false );
+        KWin::clearState(winId(), NET::SkipTaskbar);
+    }
+}
+
+void MainWindow::updateWindowAttr()
+{
+    if (KDE::versionMajor() == 3 && KDE::versionMinor() <= 1) {
+        // reapply staysOnTop flag because it gets lost during the view change
+        // we only do this for kde version < 3.2 because this seems to be fixed there
+        if(_staysOnTop) {
+            KWin::setState(winId(), NET::StaysOnTop);
+            setWFlags(WStyle_StaysOnTop);
+        }
+
+        KWin::setOnAllDesktops(winId(), _sticky &&
+                               !(_noStickyFull && (_viewMode == ViewFullScreen)));
+    }
+}
+
 void MainWindow::nextViewMode()
 {
     kdDebug() << "MainWindow::nextViewMode() Current is " << _viewMode << endl;
@@ -710,23 +786,17 @@ void MainWindow::toggleFullScreen()
 
 void MainWindow::setViewMode( int mode )
 {
+    saveWindowSettings();
     _changingViewMode = true;
-    doSetViewMode( _viewMode, false );
-    doSetViewMode( mode,      true  );
+    doSetViewMode( _viewMode, false ); // clean up last view mode
+    doSetViewMode( mode,      true  ); // init new view mode
     _changingViewMode = false;
     emit viewModeChanged( _viewMode );
 
     // give the TV widget focus
     _screen->view()->setFocus();
-#if KDE_VERSION < KDE_MAKE_VERSION(3, 2, 0)
-    if (KDE::versionMajor() == 3 && KDE::versionMinor() <= 1 && _staysOnTop)
-    {
-	// reapply staysOnTop flag because it gets lost during the view change
-	// we only do this for kde version < 3.2 because this seems to be fixed there
-	KWin::setState(winId(), NET::StaysOnTop);
-	setWFlags(WStyle_StaysOnTop);
-    }
-#endif
+
+    updateTaskbarButton();
 }
 
 void MainWindow::doSetViewMode( int mode, bool enable )
@@ -748,8 +818,8 @@ void MainWindow::doSetViewMode( int mode, bool enable )
         setShowVideoDesktop( enable );
         break;
     default:
-        kdDebug() << "MainWindow::setViewMode(): Unknown mode " << mode
-                  << ", defaulting to ViewNormal" << endl;
+        kdWarning() << "MainWindow::setViewMode(): Unknown mode " << mode
+                    << ", defaulting to ViewNormal" << endl;
         setShowNormal( enable );
         break;
     }
@@ -780,18 +850,14 @@ void MainWindow::setShowTV( bool enable )
     kdDebug() << "MainWindow::setShowTV(): " << enable << endl;
     if (enable) {
         hideGUIElements();
-        setShowTrayIcon( true );
-        //        setWFlags( WStyle_Customize | WStyle_Tool );
-        move( _topLevelPos );
+        topLevelWidget()->move( _topLevelPos );
         resize( _topLevelSize );
-        QTimer::singleShot(1, this, SLOT(bringToFront()));
+        QTimer::singleShot(0, this, SLOT(bringToFront()));
         _viewMode = ViewTV;
         _actShowTV->setChecked( true );
     } else {
-        //        clearWFlags( WStyle_Customize | WStyle_Tool );
-        setShowTrayIcon( false );
         restoreGUIElements();
-        move( _pos );
+        topLevelWidget()->move( _pos );
         resize( _size );
     }
 }
@@ -808,17 +874,30 @@ void MainWindow::setShowFullScreen( bool enable )
         }
         _screen->driver()->sourceManager()->viewModeHint(SourceManager::Fullscreen);
         hideGUIElements();
-        showFullScreen();
+        if(_haveKWin) {
+            KWin::setState(winId(), NET::FullScreen);
+        } else {
+            showFullScreen();
+        }
         _bgcol = paletteBackgroundColor();
         setPaletteBackgroundColor( QColor( 0, 0, 0 ) );
         QTimer::singleShot(1, this, SLOT(bringToFront()));
+        _wasSticky = KWin::windowInfo(winId()).onAllDesktops();
+        if(_noStickyFull) {
+            KWin::setOnAllDesktops(winId(), false);
+        }
         _viewMode = ViewFullScreen;
         _actShowFull->setChecked( true );
     } else {
         setPaletteBackgroundColor( _bgcol );
         _screen->driver()->sourceManager()->viewModeHint(SourceManager::Windowed);
         restoreGUIElements();
-        showNormal();
+        if(_haveKWin) {
+            KWin::clearState(winId(), NET::FullScreen);
+        } else {
+            showNormal();
+        }
+        KWin::setOnAllDesktops(winId(), _wasSticky);
         KWin::setIcons( winId(), _icon, _miniIcon );
     }
 }
@@ -841,8 +920,7 @@ void MainWindow::setShowVideoDesktop( bool enable )
 
 void MainWindow::bringToFront()
 {
-    setActiveWindow();
-    raise();
+    KWin::activateWindow(winId());
 }
 
 void MainWindow::hideGUIElements()
@@ -853,7 +931,6 @@ void MainWindow::hideGUIElements()
 
     _statusbarVisible = !statusBar()->isHidden();
     statusBar()->hide();
-    _actShowStatusbar->setEnabled(false);
 
     _sidebarVisible = !_sideDock->isHidden();
     setSidebarVisibility(false);
@@ -883,9 +960,7 @@ void MainWindow::restoreGUIElements()
 
     if (_statusbarVisible) {
         statusBar()->show();
-        _actShowStatusbar->setChecked(true);
     }
-    _actShowStatusbar->setEnabled(true);
 
     setSidebarVisibility(_sidebarVisible);
     _actShowSidebar->setEnabled(true);
@@ -899,14 +974,14 @@ void MainWindow::restoreGUIElements()
     }
 }
 
-void MainWindow::moveEvent( QMoveEvent* e )
+void MainWindow::moveEvent(QMoveEvent*)
 {
     if (_changingViewMode) return;
 
     if (_viewMode == ViewTV) {
-        _topLevelPos = e->pos();
+        _topLevelPos = topLevelWidget()->pos();
     } else if (_viewMode == ViewNormal) {
-        _pos = e->pos();
+        _pos = topLevelWidget()->pos();
     }
 }
 
