@@ -21,8 +21,8 @@
  *
  * You should have received a copy of the GNU Library General Public License
  * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * the Free Software Foundation, Inc., 51 Franklin Steet, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #include <qlistview.h>
@@ -37,11 +37,7 @@
 #include <kdebug.h>
 #include <kdeversion.h>
 
-#if KDE_VERSION >= KDE_MAKE_VERSION(3, 1, 93)
 #include <kinputdialog.h>
-#else
-#include <klineeditdlg.h>
-#endif
 
 #include <kiconloader.h>
 #include <klistview.h>
@@ -54,7 +50,6 @@
 #include "channelstore.h"
 #include "channelwidgetimpl.h"
 #include "channelwidgetimpl.moc"
-#include "channelpropertiesdialogimpl.h"
 #include "kdetv.h"
 #include "sourcemanager.h"
 
@@ -146,12 +141,10 @@ ChannelWidgetImpl::ChannelWidgetImpl(QWidget *parent, Kdetv *ktv, ConfigData *cf
     // call slotRenameItem when the user renames the seleted item
     connect(_listview, SIGNAL(itemRenamed(QListViewItem *)),
             this, SLOT(slotRenameItem(QListViewItem *)));
-    // a double click will raise the edit dialogue
+    // a double click will raise the edit dialog
     connect(_listview, SIGNAL(doubleClicked(QListViewItem*)),
             this, SLOT(slotEditClicked()));
 
-    connect(_renumber, SIGNAL(clicked()), this, SLOT(slotRenumberClicked()));
-    connect(_display, SIGNAL(clicked()), this, SLOT(slotChangeChannel()));
     connect(_new, SIGNAL(clicked()), this, SLOT(slotNewClicked()));
     connect(_edit, SIGNAL(clicked()), this, SLOT(slotEditClicked()));
 
@@ -198,12 +191,10 @@ void ChannelWidgetImpl::updateChannels()
 void ChannelWidgetImpl::setup()
 {
     createChannelList(_cs);
-    _setChannel->setChecked(_cfg->setChannelOnSelect);
 }
 
 void ChannelWidgetImpl::apply()
 {
-    _cfg->setChannelOnSelect = _setChannel->isChecked();
     updateChannels();
     _ktv->saveChannels();
 }
@@ -257,15 +248,11 @@ void ChannelWidgetImpl::slotListItemClicked()
         _edit->setEnabled(true);
         _rename->setEnabled(true);
         _remove->setEnabled(true);
-        _display->setEnabled(true);
         _moveUp->setEnabled(true);
         _moveDown->setEnabled(true);
     }
 
-    if ( _setChannel->isChecked() ) {
-        slotChangeChannel();
-    }
-
+    slotChangeChannel();
     return;
 } // slotListItemClicked
 
@@ -279,10 +266,8 @@ void ChannelWidgetImpl::slotRenameClicked()
 
     ChannelListViewItem *clvi = static_cast<ChannelListViewItem*>(lvi);
 
-#if KDE_VERSION >= KDE_MAKE_VERSION(3, 1, 93)
-
     bool ok;
-    QString text = KInputDialog::getText(i18n("Rename channel"),
+    QString text = KInputDialog::getText(i18n("Rename Channel"),
                                          i18n("Please enter a new name for this channel:"),
                                          clvi->text(1),
                                          &ok,
@@ -290,23 +275,7 @@ void ChannelWidgetImpl::slotRenameClicked()
     if (!ok)
         return;
 
-    clvi->c->updateValues(text, clvi->c->number(), clvi->c->freq(),
-                          clvi->c->enabled(), clvi->c->encoding(), clvi->c->source());
-
-#else
-
-    // This can be removed around the time when KDE 4 or 3.3 ships...
-    KLineEditDlg *inputBox = new KLineEditDlg(i18n("Please enter a new name for this channel:"),
-                                              clvi->text(1),
-                                              this);
-    inputBox->exec();
-    if (!inputBox->result())
-        return;
-
-    clvi->c->updateValues(inputBox->text(), clvi->c->number(), clvi->c->freq(),
-                          clvi->c->enabled(), clvi->c->encoding(), clvi->c->source());
-
-#endif
+    clvi->c->updateValues(text, clvi->c->number(), clvi->c->enabled());
 
     return;
 } // slotRenameClicked
@@ -331,6 +300,8 @@ void ChannelWidgetImpl::slotRemoveClicked()
         _cs->removeChannel(l->c);
     }
 
+    _cs->renumber();
+
     QListViewItem * currentItem = _listview->currentItem();
     if (currentItem) {
         _listview->selectAll(false);
@@ -338,22 +309,19 @@ void ChannelWidgetImpl::slotRemoveClicked()
     } else {
         _edit->setEnabled(false);
         _rename->setEnabled(false);
-        _display->setEnabled(false);
         _remove->setEnabled(false);
         _moveUp->setEnabled(false);
         _moveDown->setEnabled(false);
     }
 }
 
-void ChannelWidgetImpl::slotRenumberClicked()
-{
-    _cs->renumber();
-}
 
 void ChannelWidgetImpl::slotNewClicked()
 {
     if (  _cs && _srcm->hasDevice() ) {
-        Channel *c = _cs->addChannel((unsigned long)1000, _srcm->encoding(), _srcm->source());
+        Channel *c = _srcm->createChannel(_cs);
+        _cs->addChannel(c);
+
         ChannelListViewItem *cli = new ChannelListViewItem(_listview, c);
         cli->setOn(c->enabled());
         _listview->ensureItemVisible(cli);
@@ -389,10 +357,7 @@ void ChannelWidgetImpl::slotEditClicked()
     QTimer::singleShot(0, this, SLOT(slotChangeChannel()));
     setItemInEditor( l );
 
-    ChannelPropertiesDialogImpl* d;
-    d = new ChannelPropertiesDialogImpl(l->c, _srcm, this, "ChannelProperties",
-                                        true, Qt::WDestructiveClose);
-
+    QDialog* d = _srcm->channelPropertiesDialog(l->c, this);
     connect(d, SIGNAL(accepted()),
             this, SLOT(slotPropertiesFinished()));
     connect(d, SIGNAL(rejected()),
@@ -414,30 +379,31 @@ void ChannelWidgetImpl::slotMoveDownClicked()
         return;
 
     ChannelListViewItem *nextItem;    // the one to swap with...
-    if (currItem == static_cast<ChannelListViewItem*>(_listview->lastItem()))
+    if (currItem == static_cast<ChannelListViewItem*>(_listview->lastItem())) {
         nextItem = 0;
-    else nextItem = static_cast<ChannelListViewItem *>(_listview->itemAtIndex( _listview->itemIndex(currItem) + 1 ));
+    } else {
+        nextItem = static_cast<ChannelListViewItem *>(_listview->itemAtIndex( _listview->itemIndex(currItem) + 1 ));
+    }
 
     if (!nextItem || nextItem->c->number() != currItem->c->number() + 1) {
         currItem->c->setNumber(currItem->c->number()+1);
+        _cs->renumber();
         currItem->updateFields();
     } else {
         // do the swap - NB! channel numbers do not change!
         Channel *tempCh = new Channel(currItem->c->parent());
-        tempCh->setValues( currItem->c );
+        *tempCh = currItem->c;
+
+        int num;
+
+        num = currItem->c->number();
+        *(currItem->c) = nextItem->c;
+        currItem->c->setNumber(num);
+
+        num = nextItem->c->number();
+        *(nextItem->c) = tempCh;
+        nextItem->c->setNumber(num);
 
-        currItem->c->updateValues(nextItem->c->name(),
-                                  currItem->c->number(),
-                                  nextItem->c->freq(),
-                                  nextItem->c->enabled(),
-                                  nextItem->c->encoding(),
-                                  nextItem->c->source());
-        nextItem->c->updateValues(tempCh->name(),
-                                  nextItem->c->number(),
-                                  tempCh->freq(),
-                                  tempCh->enabled(),
-                                  tempCh->encoding(),
-                                  tempCh->source());
         delete tempCh;
 
         // update the display
@@ -448,7 +414,7 @@ void ChannelWidgetImpl::slotMoveDownClicked()
         _listview->setCurrentItem(nextItem);
         _listview->ensureItemVisible(nextItem);
     }
-} // slotMoveUpClicked
+} // slotMoveDownClicked
 
 
 void ChannelWidgetImpl::slotMoveUpClicked()
@@ -467,25 +433,24 @@ void ChannelWidgetImpl::slotMoveUpClicked()
     if (!nextItem || nextItem->c->number() != currItem->c->number() - 1) {
         if (currItem->c->number() > 1) {
             currItem->c->setNumber(currItem->c->number()-1);
+            _cs->renumber();
             currItem->updateFields();
         }
     } else {
         // do the swap - NB: channel numbers do not change!
         Channel *tempCh = new Channel(currItem->c->parent());
-        tempCh->setValues( currItem->c );
+        *tempCh = currItem->c;
+
+        int num;
+
+        num = currItem->c->number();
+        *(currItem->c) = nextItem->c;
+        currItem->c->setNumber(num);
+
+        num = nextItem->c->number();
+        *(nextItem->c) = tempCh;
+        nextItem->c->setNumber(num);
 
-        currItem->c->updateValues(nextItem->c->name(),
-                                  currItem->c->number(),
-                                  nextItem->c->freq(),
-                                  nextItem->c->enabled(),
-                                  nextItem->c->encoding(),
-                                  nextItem->c->source());
-        nextItem->c->updateValues(tempCh->name(),
-                                  nextItem->c->number(),
-                                  tempCh->freq(),
-                                  tempCh->enabled(),
-                                  tempCh->encoding(),
-                                  tempCh->source());
         delete tempCh;
 
         // update the display
@@ -499,7 +464,7 @@ void ChannelWidgetImpl::slotMoveUpClicked()
     }
 
     return;
-} // slotMoveDownClicked
+} // slotMoveUpClicked
 
 
 void ChannelWidgetImpl::slotRenameItem(QListViewItem *item)
@@ -541,10 +506,9 @@ void ChannelWidgetImpl::slotKillDoublesClicked()
                       kdDebug() << "Check Current: (" << pl->c->number() << "):" << pl->c->name() << ", " \
                       << pl->c->freq() << ", " << pl->c->source() << endl;
                     */
-                    if ((l->c->freq() == pl->c->freq()) && (l->c->source() == pl->c->source())) {
-                        // should we check for enabled and encoding here, too?
+                    if (l->c->compareChannelProperties(*pl->c)) {
                         kdDebug() << "Duplicate: (" << pl->c->number() << "):" << pl->c->name() << ", (" \
-                                  << l->c->number() << "):" << l->c->name() << ", " << l->c->freq() << endl;
+                                  << l->c->number() << "):" << l->c->name() << endl;
                         dli = l;
                         break;
                     }
@@ -565,6 +529,8 @@ void ChannelWidgetImpl::slotKillDoublesClicked()
         }
     }
 
+    _cs->renumber();
+
     QListViewItem * currentItem = _listview->currentItem();
     if (currentItem) {
         _listview->selectAll(false);
@@ -572,7 +538,6 @@ void ChannelWidgetImpl::slotKillDoublesClicked()
     } else {
         _edit->setEnabled(false);
         _rename->setEnabled(false);
-        _display->setEnabled(false);
         _remove->setEnabled(false);
         _moveUp->setEnabled(false);
         _moveDown->setEnabled(false);
