@@ -16,8 +16,8 @@
  *
  * You should have received a copy of the GNU Library General Public License
  * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * the Free Software Foundation, Inc., 51 Franklin Steet, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 
@@ -34,7 +34,7 @@ class KdetvMiscPluginPrivate;
 /**
  * Misc plugin base class
  */
-class KdetvMiscPlugin : public KdetvPluginBase
+class KDETV_EXPORT KdetvMiscPlugin : public KdetvPluginBase
 {
     Q_OBJECT
 
