@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU Library General Public License
  * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * the Free Software Foundation, Inc., 51 Franklin Steet, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #include <kdebug.h>
@@ -35,6 +35,11 @@ KdetvSourcePlugin::~KdetvSourcePlugin()
 {
 }
 
+bool KdetvSourcePlugin::setVolume( int, int )
+{
+    return false;
+}
+
 bool KdetvSourcePlugin::isTuner(const QString &dev)
 {
 	kdDebug() << "-->" << _tuners.size() << " tuners detected" << endl;
