@@ -13,11 +13,11 @@
  
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Steet, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
-// $Id: channelioxawtv.h,v 1.6 2004/03/23 22:00:22 dziegel Exp $
+// $Id: channelioxawtv.h 439804 2005-07-28 23:45:59Z mueller $
 
 #ifndef CHANNELIOXAWTV_H
 #define CHANNELIOXAWTV_H
@@ -29,8 +29,8 @@ class ChannelIOFormatXawtv : public KdetvChannelPlugin
 public:
 	ChannelIOFormatXawtv(Kdetv *ktv, QObject *parent = 0L, const char *name = 0L);
 
-	virtual bool load(ChannelStore *store, const QString &filename, const QString& fmt);
-	virtual bool save(ChannelStore* store, QIODevice* file, const QString& fmt);
+	virtual bool load(ChannelStore *store, ChannelFileMetaInfo *info,
+                      const QString &filename, const QString& fmt);
 
 private:
 	struct ChannelInfo;
