@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU Library General Public License
  * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * the Free Software Foundation, Inc., 51 Franklin Steet, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 
@@ -36,6 +36,7 @@ k_dcop:
     virtual void showDisplay(bool show) = 0;
     virtual void toggleShow() = 0;
     virtual void toggleTransparent() = 0;
+    virtual void toggleReveal() = 0;
 
     virtual void navigate(int page) = 0;
     virtual void nextPage() = 0;
